Connect to Spotify API
spotify_auth.RdAuthenticates with Spotify and gets user authorization. You'll need to create a Spotify App first at https://developer.spotify.com/dashboard
spotify_auth.RdAuthenticates with Spotify and gets user authorization. You'll need to create a Spotify App first at https://developer.spotify.com/dashboard