Plot Lyrical Themes
plot_themes.RdCreates a bar chart of the top theme keyword matches found in the lyrics. Only themes with at least one match are shown, up to a maximum of 10.
Arguments
- analysis_result
Result from analyze_playlist()
- lyrics_obj
Lyrics object from
get_lyrics()
Examples
if (FALSE) { # \dontrun{
lyrics <- get_lyrics("Adele", "Someone Like You")
plot_themes(lyrics)
} # }